==> haskell-patience-0.3-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-patience.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 patience
version:              0.3
visibility:           public
id:                   patience-0.3-5ZHwccvCPDg8zBxzllTHqS
key:                  patience-0.3-5ZHwccvCPDg8zBxzllTHqS
license:              BSD-3-Clause
maintainer:           chessai <chessai1996@gmail.com>
author:
    Keegan McAllister <mcallister.keegan@gmail.com>
    chessai <chessai1996@gmail.com>

homepage:             https://github.com/chessai/patience
synopsis:             Patience diff and longest increasing subsequence
description:
    This library implements the \"patience diff\" algorithm, as well as the patience
    algorithm for the longest increasing subsequence problem.

    Patience diff computes the difference between two lists, for example the
    lines of two versions of a source file.  It provides a good balance of
    performance, nice output for humans, and implementation simplicity.  For more
    information, see <http://alfedenzo.livejournal.com/170301.html> and
    <http://bramcohen.livejournal.com/73318.html>.

category:             Algorithms, Text
abi:                  107a1273715a1dcdcd194706a8e70b31
exposed:              True
exposed-modules:      Patience Patience.Map
import-dirs:          /usr/lib/ghc-9.2.8/site-local/patience-0.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/patience-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-patience
hs-libraries:         HSpatience-0.3-5ZHwccvCPDg8zBxzllTHqS
depends:              base-4.16.4.0 containers-0.6.5.1
haddock-interfaces:   /usr/share/doc/haskell-patience/html/patience.haddock
haddock-html:         /usr/share/doc/haskell-patience/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-patience-0.3-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-patience.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 patience
version:              0.3
visibility:           public
id:                   patience-0.3-76KPiSxHJ2U3wboHHGuXu
key:                  patience-0.3-76KPiSxHJ2U3wboHHGuXu
license:              BSD-3-Clause
maintainer:           chessai <chessai1996@gmail.com>
author:
    Keegan McAllister <mcallister.keegan@gmail.com>
    chessai <chessai1996@gmail.com>

homepage:             https://github.com/chessai/patience
synopsis:             Patience diff and longest increasing subsequence
description:
    This library implements the \"patience diff\" algorithm, as well as the patience
    algorithm for the longest increasing subsequence problem.

    Patience diff computes the difference between two lists, for example the
    lines of two versions of a source file.  It provides a good balance of
    performance, nice output for humans, and implementation simplicity.  For more
    information, see <http://alfedenzo.livejournal.com/170301.html> and
    <http://bramcohen.livejournal.com/73318.html>.

category:             Algorithms, Text
abi:                  d08313fe6394125264b9ce4d2c6449ba
exposed:              True
exposed-modules:      Patience Patience.Map
import-dirs:          /usr/lib/ghc-9.4.8/site-local/patience-0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/patience-0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/patience-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-patience
hs-libraries:         HSpatience-0.3-76KPiSxHJ2U3wboHHGuXu
depends:              base-4.17.2.1 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-patience/html/patience.haddock
haddock-html:         /usr/share/doc/haskell-patience/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
